@@ -30,7 +30,7 @@ BEGIN {
     }
 }
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 sub _ANYPROCESS                    { return -1 }
 sub _COMMAND                       { return 0 }
@@ -119,6 +119,7 @@ sub _launch {
     }
     elsif (( $OSNAME ne 'darwin' )
         && ( $OSNAME ne 'cygwin' )
+        && ( $self->_visible() )
         && ( !$ENV{DISPLAY} )
         && ( $self->_xvfb_exists() ) )
     { # if not MacOS or Win32 and no DISPLAY variable, launch Xvfb if at all possible
@@ -127,16 +128,6 @@ sub _launch {
         local $ENV{XAUTHORITY} = $self->_xvfb_xauthority();
         return $self->_launch_unix(@arguments);
     }
-    elsif (( $OSNAME ne 'darwin' )
-        && ( $OSNAME ne 'cygwin' )
-        && ( !$self->_visible() )
-        && ( $self->_xvfb_exists() ) )
-    {    # in headless mode, launch Xvfb if at all possible
-        $self->_launch_xvfb();
-        local $ENV{DISPLAY}    = $self->_xvfb_display();
-        local $ENV{XAUTHORITY} = $self->_xvfb_xauthority();
-        return $self->_launch_unix(@arguments);
-    }
     else {
         return $self->_launch_unix(@arguments);
     }
@@ -1593,11 +1584,6 @@ sub _send_request {
     my ( $self, $object ) = @_;
     my $json   = JSON::encode_json($object);
     my $length = length $json;
-if (!defined $self->_socket()) {
-	use Data::Dumper;
-	print STDERR Dumper($self);
-	Carp::cluck("WTF");
-}
     my $result = syswrite $self->_socket(), "$length:$json";
     if ( !defined $result ) {
         Carp::croak("Failed to send request to firefox:$EXTENDED_OS_ERROR");
@@ -1679,7 +1665,7 @@ Firefox::Marionette - Automate the Firefox browser with the Marionette protocol
 
 =head1 VERSION
 
-Version 0.22
+Version 0.23
 
 =head1 SYNOPSIS
 
@@ -1726,7 +1712,7 @@ accepts an optional hash as a parameter.  Allowed keys are below;
 
 =back
 
-This method returns a new C<Firefox::Marionette> object, connected to an instance of L<firefox|https://firefox.com>.  If necessary and possible, this method will also automatically start an L<Xvfb|https://en.wikipedia.org/wiki/Xvfb> instance to allow firefox to run in an environment without an accessible X server, so long as the method is not being run on Windows or MacOS.
+This method returns a new C<Firefox::Marionette> object, connected to an instance of L<firefox|https://firefox.com>.  In a non MacOS/Win32/Cygwin environment, if necessary (no DISPLAY variable can be found and visible has been set to true) and possible (Xvfb can be executed successfully), this method will also automatically start an L<Xvfb|https://en.wikipedia.org/wiki/Xvfb> instance.
  
 =head2 go
 
